﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Globalization;
using System.Windows;
using System.Windows.Data;
using Telerik.Windows.Data;

namespace WpfApp10
{
    public partial class MainWindow : Window
    {
        private ObservableCollection<IncidentItemViewModel> incidents;

        public MainWindow()
        {
            InitializeComponent();

            this.incidents = new ObservableCollection<IncidentItemViewModel>();
            AddIncidentItemViewModelsFromResultToIncidents();
            var qcv = GetInitializedIncidentCollectionView(incidents);
            qcv.FilterDescriptors.Add(new FilterDescriptor()
            {
                Member = "Number",
                Operator = FilterOperator.Contains,
                Value = "10",
                MemberType = typeof(string)
            });
            this.DataContext = qcv;
    }

        private QueryableCollectionView GetInitializedIncidentCollectionView(INotifyCollectionChanged incidents)
        {
            var result = (ListCollectionView)CollectionViewSource.GetDefaultView(incidents);
            //result.CustomSort = new IncidentItemComparer();
            result.Culture = CultureInfo.CurrentCulture;

            var collectionViewLiveShaping = (ICollectionViewLiveShaping)result;
            collectionViewLiveShaping.IsLiveSorting = true;
            collectionViewLiveShaping.LiveSortingProperties.Add(nameof(IncidentItemViewModel.IncidentPriority));
            collectionViewLiveShaping.LiveSortingProperties.Add(nameof(IncidentItemViewModel.NeedsAttention));
            collectionViewLiveShaping.LiveSortingProperties.Add(nameof(IncidentItemViewModel.ConfirmedBy));
            collectionViewLiveShaping.LiveSortingProperties.Add(nameof(IncidentItemViewModel.StartedAtLocal));

            return new QueryableCollectionView(result);
        }

        private void AddIncidentItemViewModelsFromResultToIncidents()
        {
            var props = typeof(IncidentItemViewModel).GetProperties();            
            for (int i = 0; i < 100; i++)
            {
                var vm = new IncidentItemViewModel();
                foreach (var p in props)
                {
                    p.SetValue(vm, p.Name + " " + i);
                }
                this.incidents.Add(vm);
            }
        }

        private void RadButton_Click(object sender, RoutedEventArgs e)
        {
            string i = "10";
            var vm = new IncidentItemViewModel()
            {
                Number = i,
                NeedsAttention = "NeedsAttention " + i,
                ConfirmedBy = "ConfirmedBy " + i,
                StartedAtLocal = "StartedAtLocal " + i,
                IncidentPriority = "IncidentPriority " + i,
                IncidentKey = "IndicidentKey " + i,
            };

            this.incidents.Add(vm);
        }
    }

    public class IncidentItemViewModel
    {
        public object NeedsAttention { get; internal set; }
        public object ConfirmedBy { get; internal set; }
        public object StartedAtLocal { get; internal set; }
        public object IncidentPriority { get; internal set; }
        public object AlarmCode { get; internal set; }
        public object AlarmText { get; internal set; }
        public object Number { get; internal set; }
        public object Date { get; internal set; }
        public object Data { get; internal set; }
        public object FacilityObjectId { get; internal set; }
        public object RemindAtLocal { get; internal set; }
        public object EndedAtLocal { get; internal set; }
        public object EstimatedEndLocal { get; internal set; }
        public object Description { get; internal set; }
        public object CreatedBy { get; internal set; }
        public object PreviouslyAssignedTo { get; internal set; }
        public object LocationText { get; internal set; }
        public object ReasonCodeName { get; internal set; }
        public object IncidentKey { get; internal set; }
        public object TranslatedPriority { get; internal set; }
        public object IncidentIcon { get; internal set; }
        public object Priority { get; internal set; }
    }
}
